==> initdecaytor-0.3-py3-none-any.whl: InitDecaytor/__init__.py <==
# -*- coding: utf-8 -*-
#
# Copyright (c) 2025 Kevin De Bruycker and Stijn D'hollander
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#

__version__ = '0.3'

import sys
import struct
from .decomposition import Simulation
from .decomposition import hlt_parms, time_factors
from .csv_temperature_profile import get_temperature_profile
from .app import GUI

# if not hasattr(sys, "version_info") or sys.version_info < (3, 6):
#     raise RuntimeError("pymacroms requires Python 3.6 or later.")
# if struct.calcsize("P") * 8 != 64:
#     raise RuntimeError("pymacroms requires Python 64 bit.")
#
# from . import database
# from .single_molecule import Molecule
# from .polymer import Polymer
# from .spectrum_processing import Spectrum
# from .import_spectrum import MSData
# from .helper_functions import *

del struct

==> initdecaytor-0.4.3-py3-none-any.whl: InitDecaytor/__init__.py <==
# -*- coding: utf-8 -*-
#
# Copyright (c) 2025 Kevin De Bruycker and Stijn D'hollander
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#

__version__ = '0.4.3'

import sys
import struct
from .decomposition import Simulation
from .decomposition import hlt_parms, time_factors
from .csv_temperature_profile import get_temperature_profile, supported_sources, source_encoding
from .app import GUI

# if not hasattr(sys, "version_info") or sys.version_info < (3, 6):
#     raise RuntimeError("pymacroms requires Python 3.6 or later.")
# if struct.calcsize("P") * 8 != 64:
#     raise RuntimeError("pymacroms requires Python 64 bit.")
#
# from . import database
# from .single_molecule import Molecule
# from .polymer import Polymer
# from .spectrum_processing import Spectrum
# from .import_spectrum import MSData
# from .helper_functions import *

del struct
